Learn R Programming

symbolicQspray (version 1.1.0)

changeParameters: Change of parameters in a 'symbolicQspray' polynomial

Description

Replaces the parameters of a symbolicQspray polynomial (which are qspray objects) with some qspray polynomials. E.g. you have a polynomial with two parameters \(P_{a,b}(x)\) and you want the polynomial \(P_{a+1,b+1}(x)\) (see example).

Usage

changeParameters(Qspray, newParameters)

Value

The symbolicQspray polynomial obtained by replacing the parameters of the symbolic polynomial given in the Qspray argument with the polynomials given in the newParameters argument.

Arguments

Qspray

a symbolicQspray polynomial

newParameters

a list containing at least n qspray objects, or objects coercible to qspray objects, where n is the number of parameters in the symbolic polynomial given in the Qspray argument; if this list is named, then its names will be used in the show options of the result

See Also

If you want to change the variables of a symbolic qspray, use changeVariables. If you want to assign some values to its parameters, use substituteParameters.

Examples

Run this code
library(symbolicQspray)
( JP <- JacobiPolynomial(2) ) # a univariate polynomial with two parameters
a1 <- qlone(1)
a2 <- qlone(2)
changeParameters(JP, list(a1, a2)) == JP # should be TRUE
changeParameters(JP, list(a1+1, a2+1))

Run the code above in your browser using DataLab