Learn R Programming

symbolicQspray (version 1.1.0)

showSymbolicQsprayABCXYZ: Print a 'symbolicQspray' object

Description

Prints a symbolicQspray object.

Usage

showSymbolicQsprayABCXYZ(
  params,
  vars = c("X", "Y", "Z"),
  quotientBar = " %//% ",
  ...
)

Value

A function which prints symbolicQspray objects.

Arguments

params

vector of strings, usually some letters, to denote the parameters of the polynomial

vars

a vector of strings, usually some letters, to denote the variables of the polynomial

quotientBar

a string for the quotient bar between the numerator and the denominator of a ratioOfQsprays object, including surrounding spaces, e.g. " / "

...

arguments other than showRatioOfQsprays and showMonomial passed to showSymbolicQspray

Examples

Run this code
set.seed(421)
( Qspray <- rSymbolicQspray() )
showSymbolicQsprayABCXYZ(c("a", "b", "c"), c("U", "V"))(Qspray)

Run the code above in your browser using DataLab