Learn R Programming

symbolicQspray (version 1.1.0)

showSymbolicQsprayX1X2X3: Print a 'symbolicQspray' object

Description

Prints a symbolicQspray object.

Usage

showSymbolicQsprayX1X2X3(a = "a", X = "X", quotientBar = " %//% ", ...)

Value

A function which prints symbolicQspray objects.

Arguments

a

a string, usually a letter, to denote the non-indexed variables of the ratioOfQsprays coefficients

X

a string, usually a letter, to denote the non-indexed variables

quotientBar

a string for the quotient bar between the numerator and the denominator of a ratioOfQsprays object, including surrounding spaces, e.g. "/"

...

arguments other than showRatioOfQsprays and showMonomial passed to showSymbolicQspray

Examples

Run this code
set.seed(421)
Qspray <- rSymbolicQspray()
showSymbolicQsprayX1X2X3(quotientBar = " / ")(Qspray)

Run the code above in your browser using DataLab