showSymbolicQsprayXYZ: Print a 'symbolicQspray' object
Description
Prints a symbolicQspray object.
Usage
showSymbolicQsprayXYZ(
a = "a",
letters = c("X", "Y", "Z"),
quotientBar = " %//% ",
...
)Value
A function which prints symbolicQspray objects.
Arguments
- a
a string, usually a letter, to denote the non-indexed variables
of the ratioOfQsprays coefficients
- letters
a vector of strings, usually some letters, to denote the
variables of the polynomial
- quotientBar
a string for the quotient bar between the numerator and
the denominator of a ratioOfQsprays object, including surrounding
spaces, e.g. " / "
- ...
arguments other than showRatioOfQsprays and
showMonomial passed to showSymbolicQspray
Examples
Run this codeset.seed(421)
Qspray <- rSymbolicQspray()
showSymbolicQsprayX1X2X3(quotientBar = " / ")(Qspray)
Run the code above in your browser using DataLab