powered by
Prints a symbolicQspray object.
symbolicQspray
showSymbolicQsprayABCXYZ( params, vars = c("X", "Y", "Z"), quotientBar = " %//% ", ... )
A function which prints symbolicQspray objects.
vector of strings, usually some letters, to denote the parameters of the polynomial
a vector of strings, usually some letters, to denote the variables of the polynomial
a string for the quotient bar between the numerator and the denominator of a ratioOfQsprays object, including surrounding spaces, e.g. " / "
ratioOfQsprays
" / "
arguments other than showRatioOfQsprays and showMonomial passed to showSymbolicQspray
showRatioOfQsprays
showMonomial
showSymbolicQspray
set.seed(421) ( Qspray <- rSymbolicQspray() ) showSymbolicQsprayABCXYZ(c("a", "b", "c"), c("U", "V"))(Qspray)
Run the code above in your browser using DataLab