powered by
Prints a symbolicQspray object.
symbolicQspray
showSymbolicQsprayX1X2X3(a = "a", X = "X", quotientBar = " %//% ", ...)
A function which prints symbolicQspray objects.
a string, usually a letter, to denote the non-indexed variables of the ratioOfQsprays coefficients
ratioOfQsprays
a string, usually a letter, to denote the non-indexed variables
a string for the quotient bar between the numerator and the denominator of a ratioOfQsprays object, including surrounding spaces, e.g. "/"
"/"
arguments other than showRatioOfQsprays and showMonomial passed to showSymbolicQspray
showRatioOfQsprays
showMonomial
showSymbolicQspray
set.seed(421) Qspray <- rSymbolicQspray() showSymbolicQsprayX1X2X3(quotientBar = " / ")(Qspray)
Run the code above in your browser using DataLab